From fa7a6293012bf785851f7b2b38975b7c29ff2df1 Mon Sep 17 00:00:00 2001
From: Aditya Vidyadhar Kamath <Aditya.Kamath1@ibm.com>
Date: Wed, 19 Oct 2022 00:53:16 -0500
Subject: [PATCH] Modify altivec-regs.exp testcase for AIX

Hi,

In AIX, unless and until the debugee uses the vector registers, one cannot fetch or write on them.

This patch ensures the completion of the execution of the line that uses vector registers first time only in AIX target.

Then the testcase will be able to set and fetch the vector registers.

For the remaining targets test case will stay as it is.
---
 gdb/testsuite/gdb.arch/altivec-regs.c   | 3 +++
 gdb/testsuite/gdb.arch/altivec-regs.exp | 5 +++++
 2 files changed, 8 insertions(+)

diff --git a/gdb/testsuite/gdb.arch/altivec-regs.c b/gdb/testsuite/gdb.arch/altivec-regs.c
index 4d4fe3f5dbb..a12297cd8bc 100644
--- a/gdb/testsuite/gdb.arch/altivec-regs.c
+++ b/gdb/testsuite/gdb.arch/altivec-regs.c
@@ -27,6 +27,9 @@ main ()
      so we don't want to execute them yet.  */
   a = 9;
   x = ((vector unsigned int) vec_splat_u8 (-2));
+
+  /* AIX altivec-regs testcase breakpoint here.  */
+
   y = ((vector unsigned int) vec_splat_u8 (1));
 	
   z = vector_fun (x, y);
diff --git a/gdb/testsuite/gdb.arch/altivec-regs.exp b/gdb/testsuite/gdb.arch/altivec-regs.exp
index 37dbccea704..a38c03278ca 100644
--- a/gdb/testsuite/gdb.arch/altivec-regs.exp
+++ b/gdb/testsuite/gdb.arch/altivec-regs.exp
@@ -57,6 +57,11 @@ if ![runto_main] then {
 
 gdb_test "set print frame-arguments all"
 
+if {[istarget "powerpc*-*-aix*"]} then {
+    gdb_breakpoint [gdb_get_line_number "AIX altivec-regs testcase breakpoint here"]
+    gdb_continue_to_breakpoint "AIX altivec-regs testcase breakpoint hits first time"
+}
+
 # set all the registers integer portions to 1
 
 for {set i 0} {$i < 32} {incr i 1} {
-- 
2.31.1

